@@ -1,5 +1,5 @@
 skip_if_no_sympy <- function() {
-  if (!have_sympy()) {
+  if (!has_sympy()) {
     skip("sympy not available for testing")
   }
 }
